The detection function parameters. A single value for halfnormal, or a vector of two values for hazard rate.
w
The maximum range of observation. Objects at distance greater than w from the observer are assumed to never be recorded.
detection.function
The detection function. Only "halfnormal" and "hazard" (hazard rate) are supported at present.
Value
The mean detection probability over the distance range [0,w].
References
Buckland S, Anderson D, Burnham K, Laake J and Borchers D (2001). Introduction to Distance Sampling: Estimating Abundance of Biological Populations. Oxford: Oxford University Press.
Clark, R. G. (2016), "Statistical efficiency in distance sampling," PLoS One, forthcoming, www.plosone.org